##################
#####
#####    This script provides the preparation workflow for copy number and genotype recognition
#####      in Illumina SNP arrays with the GAP method (Genome Biology, 2009, Popova et al)
#####      namesly, 
#####     1) segmentation of CN(copy number) and AD (allelic differences) profiles by CBS
#####     2) construction of segmented summary file for further analysis with GAP method
#####
#####    As an input we use vector forms of (1)Log R ratio and (2) B allele frequency, 
#####    As vector annotation we use IllumXXXk_SNP_short_annot.csv file   
#####
#####
#####    The input vectors from Vectors_and_Segmentations folder: V_LRR_Sample1,V_BAF_Sample1
#####   
#####    The output segmented summary files : segm_Sample1  are saved in Vectors_and_Segmentations folder
#####    
#####
##################

rm(list=ls())

###############################################
### File paths and other parameters

### !!!!! Put the PATH to your data  !!!!

pPath<-"C:/GAP_Illumina_workflow_homepage/"

inputPath<-paste(pPath,"Vectors_and_segmentations/",sep="")
outputPath<-paste(pPath,"Vectors_and_segmentations/",sep="")


### Annotation file

SNP_annot<-read.csv(paste(pPath,"SNP_annot_Version.csv",sep=""),header=T,fill=T,stringsAsFactors = F,row.names=1)
C_Ind<-1;C_Chr<-2;C_Pos<-4
nSNP<-dim(SNP_annot)[[1]]


### Source file need SNP_annot file defined above

source(paste(pPath,"script_functions_GAP_recognition_Illumina.R",sep=""))


####  !!!! Thresholds !!!! Correct, if necessary

germHomozyg.mBAF.thr<-0.93
germHomozyg.length.min<-100
germHomozyg.outlier<-(1/25)



#### !!!!  All V_LRR_Sample1 files form Vectors_and_Segmentations folder will be processed  !!!!


segFiles <- list.files(inputPath, pattern=vect_LR_pattern,full.names=T) 

fileNames <- gsub(inputPath,"",segFiles) 
fileNames <- gsub(vect_LR_pattern,"",fileNames) 
fileNames <- gsub(".txt","",fileNames) 

fileNames
nSample<-length(segFiles)


#########################    MAIN CYCLE   ########################

ii<-1

for(ii in 1:nSample){

print(ii)

tmp<-CBS_breakpoints_and_GAPconstruction(ii,germHomoThr=germHomozyg.mBAF.thr)

plot(tmp[,c_baf],tmp[,c_lrr],cex=tmp[,c_len]/quantile(tmp[,c_len],prob=0.9),main=paste("GAP ",fileNames[ii]),
                xlab="Allelic Difference",ylab="Log ratio")
abline(v=0.5)
abline(h=0)

fName<-paste(outputPath,vect_Segm_pattern,fileNames[ii],".txt",sep="")
write.table(tmp, file = fName,quote=F,row.names=F,sep="\t")

}#ii

#################### END MAIN CYCLE   ######################################







