rm(list=ls())

#############################################################################
#######
#######		 This script provides the preliminary GAP Pattern recognition
#######		 It is useful to check the quality of automatic recognition pattern 
#######                and correct it manually if it is possible.
#######            If you do not see any clear pattern, it means that the sample is
#######               very contaminated or of a poor quality.
#######                You may decide to exclude this sample.
#######
#######            As a result you will see GAP plots in GAP_plots folder and
#######                  GAP parameters file in Vectors_and_Segmentations folder.
#######
#############################################################################

### !!!!! Put the PATH to your data  !!!!

pPath<-"C:/GAP_Illumina_workflow_homepage/"

inputPath<-paste(pPath,"Vectors_and_segmentations/",sep="")
outputPath<-paste(pPath,"Results_Plots/",sep="")
outputPath_Plot<-paste(pPath,"Plots_GAP/",sep="")


#### Annotation file
### !!!!! Correct the name of annotation file, if necessary  !!!!

SNP_annot<-read.csv(paste(pPath,"SNP_annot_Version.csv",sep=""),header=T,fill=T,stringsAsFactors = F,row.names=1)
C_Ind<-1;C_Chr<-2;C_Pos<-4
nSNP<-dim(SNP_annot)[[1]]

### Source file needs SNP_annot file defined above

source(paste(pPath,"script_functions_GAP_recognition_Illumina.R",sep=""))

### !!!!! Give your favorit name to GAP_parameters_file_name, if you want   !!!!

GAP_parameters_file_name<-"GAP_parameters_Example"


### !!!!! All segm_Sample1 files from Vectors_and_Segmentations folder will be processed !!!!

segFiles <- list.files(inputPath, pattern=vect_Segm_pattern,full.names=T) 

fileNames <- gsub(inputPath,"",segFiles) 
fileNames <- gsub(vect_Segm_pattern,"",fileNames) 
fileNames <- gsub(".txt","",fileNames) 

fileNames
nSample<-length(segFiles)

### Output matrix of coefficients

matrCoef<-matrix(0,nSample,4)
matrCoef[,1]<-seq(1,nSample)
rownames(matrCoef)<-c(1:nSample)
colnames(matrCoef)<-c("num_Sample","p_BAF","q_LRR","2copy_LRR")


################   MAIN CYCLE

ii<-1

for(ii in 1:nSample){

print(paste(as.character(ii),"out of",as.character(nSample),"processing",fileNames[ii],sep="  "))


tmp<-read.delim(segFiles[ii],header=T,sep="\t")


notNAs<-sort(intersect(which(!is.na(tmp[,c_lrr]+tmp[,c_baf])),which(tmp[,c_chr]<23)))

plot(tmp[notNAs,c_baf],tmp[notNAs,c_lrr],cex=tmp[notNAs,c_len]/quantile(tmp[notNAs,c_len],prob=0.9),ylim=c(max(-2,min(tmp[notNAs,c_lrr])),min(2,max(tmp[notNAs,c_lrr]))),
		main="GAP",xlab="B allele frequency",ylab="Log R ratio")
abline(v=0)
abline(v=0.5)


result<-CopyNumber_and_Genotype(tmp[notNAs,c_lrr],tmp[notNAs,c_baf],tmp[notNAs,c_len],showGAPTemplate=T)


### coefficients of the pattern shrinkage
p_BAF<-result$coeff[1]
q_LRR<-result$coeff[2]

### matrix of coordinates of claster centers
Centr_CL<-result$Centr_CL

### matrix of clusters on the LRR x BAF plane
NETM<-result$NETM

### matrix of coordinates of subclones
SB_CL<-result$SB_CL

rm(result)

	matrCoef[ii,2]<-p_BAF
	matrCoef[ii,3]<-q_LRR
	matrCoef[ii,4]<-Centr_CL[5,3]
	rownames(matrCoef)[ii]<-fileNames[ii]

GAPplot_preliminary(tmp,outputPath_GAP=outputPath_Plot,nameSample=fileNames[ii],Centr_CL,p_BAF,q_LRR)


}#ii

################ END MAIN CYCLE

matrCoef<-round(matrCoef,3)

fName<-paste(inputPath,GAP_parameters_file_name,".csv",sep="")
write.table(matrCoef, file = fName,col.names=NA,row.names=T,quote=F,sep=",")

##############  END AUTOMATICAL FITTING











################ MANUAL FITTING  (ALL commands before the MAIN CYCLE should be executed!!!!)

fileNames

### !!!!! Chose number of sample for manual fitting  !!!!!!!
     
      ii<-5

	print(paste("processing  ",fileNames[ii]))
	tmp<-read.delim(segFiles[ii],header=T,sep="\t")
	tmp<-data.matrix(tmp)

	notNAs<-which(!is.na(tmp[,c_lrr]+tmp[,c_baf]))


########### MANUAL FITTING CYCLE

### !!!!! step 1. Chose the parameters you feel are better than automatically detected ones

p_BAF<-0.2;q_LRR<-0.4;Delta<-c(2,-0.0)

### Delta is vector of 2 values: c(Copy number, LRR of this Copy number)

### !!!!! step 2.  See the results

result<-CopyNumber_and_GenotypeWOfitting(tmp[notNAs,c_lrr],tmp[notNAs,c_baf],tmp[notNAs,c_len],showGAPTemplate=T,p_BAF,q_LRR,Delta)

### !!!!! Go back to step 1 until you find a good combination.

########## END MANUAL FITTING CYCLE

### !!!!!  step 3.  Open GAP_parameters_file in excel and correct it manually.

