rm(list=ls())
###############################################################
####
####  Copy Number Update in Illuymina arrays
####
####   This procedure takes segm_Sample1 files, applies GAP parameters from GAP_parameters_file,
####     and then it takes proc_Sample1 and updates all grafical outputs, proc_Sample1 will not be overwritten.
####
####    Results are saved in Results_Plots folder as: 
####
####      (2) Chr_Plot_Sample1 per chromosome profiles .jpg
####      (3) Summary_Plot_Sample1 summary profiles and information
####      (4) GAP_Plot_Sample1 plot of GAP and copy number detection
####
####  The procedure is usefull, if some obvious mistakes are corrected manualy. 
####
##################################################################


### !!!!! Put the PATH to your data  !!!!


pPath<-"C:/GAP_Illumina_workflow_homepage/"

inputPath<-paste(pPath,"Vectors_and_Segmentations/",sep="")
outputPath<-paste(pPath,"Results_Plots/",sep="")


#### Annotation file
### !!!!! Correct the name of annotation file, if necessary  !!!!

SNP_annot<-read.csv(paste(pPath,"SNP_annot_Version.csv",sep=""),header=T,fill=T,stringsAsFactors = F,row.names=1)
C_Ind<-1;C_Chr<-2;C_Pos<-4
nSNP<-dim(SNP_annot)[[1]]


### Source file needs SNP_annot file defined above
source(paste(pPath,"script_functions_GAP_recognition_Illumina.R",sep=""))

### !!!!! Give your favorit name to output_infoFileName, if you want   !!!!
output_infoFileName<-"GAPrecognitionInfo.txt"


### !!!!! Check the GAP_parameters_file_name, te be the same as after script_3   !!!!
GAP_parameters_file_name<-"GAP_parameters_Example.csv"


if(file.access(paste(inputPath,GAP_parameters_file_name,sep=""), mode = 0)==0){
	GAP_par_exist<-T
	GAP_parameters_file<-read.csv(paste(inputPath,GAP_parameters_file_name,sep=""),stringsAsFactors = F,header=T,row.names=1)
}else{GAP_par_exist<-F}


######## Structure of output summary information file concerning recognition
######## and rearrangements for all samples in the list

info<-c("p_BAF","q_LRR","2copyLRR","Breaks","DNAindex","Ploidy","Chr_counts")
cat(c("SampleID",info), file = paste(outputPath,output_infoFileName,sep=""),sep="\t","\n")


### !!!!! All segm_Sample1 files from Vectors_and_Segmentations folder will be processed !!!!

segFiles <- list.files(inputPath, pattern=vect_Segm_pattern,full.names=T) 

fileNames <- gsub(inputPath,"",segFiles) 
fileNames <- gsub(vect_Segm_pattern,"",fileNames) 
fileNames <- gsub(".txt","",fileNames) 

fileNames

nSample<-length(segFiles)


####################   MAIN CYCLE   #####################################

ii<-1

for(ii in 1:nSample){

print(paste(as.character(ii),"out of",as.character(nSample),"processing",fileNames[ii],sep="  "))

tmp<-read.delim(segFiles[ii],header=T,sep="\t")

notNAs<-sort(intersect(which(!is.na(tmp[,c_lrr]+tmp[,c_baf])),which(tmp[,c_chr]<23)))

plot(tmp[notNAs,c_baf],tmp[notNAs,c_lrr],cex=tmp[notNAs,c_len]/quantile(tmp[notNAs,c_len],prob=0.9),ylim=c(max(-2,min(tmp[notNAs,c_lrr])),min(2,max(tmp[notNAs,c_lrr]))),
		main="GAP",xlab="B allele frequency",ylab="Log R ratio")
abline(v=0)
abline(v=0.5)


GAP_parameters<-F

if(GAP_par_exist){
ii_name<-grep(fileNames[ii],rownames(GAP_parameters_file))
if(length(ii_name)!=1){
if(length(ii_name)>1){
	ii_name1<-numeric(0)
	for(i in 1:length(ii_name)){ii_name1<-c(ii_name1,grep(rownames(GAP_parameters_file)[ii_name[i]],fileNames[ii]))}
	if(length(ii_name1)==1){ii_name<-ii_name[ii_name1];GAP_parameters<-T}
}
}else{GAP_parameters<-T}
}

if(GAP_parameters){

### If precalculated GAP parameters: case 1.

p_BAF<-GAP_parameters_file[ii_name,2];q_LRR<-GAP_parameters_file[ii_name,3];Delta<-c(2,GAP_parameters_file[ii_name,4])
result<-CopyNumber_and_GenotypeWOfitting(tmp[notNAs,c_lrr],tmp[notNAs,c_baf],tmp[notNAs,c_len],showGAPTemplate=T,p_BAF,q_LRR,Delta)

}else{

### If calculating GAP parameters de novo: case 3.

result<-CopyNumber_and_Genotype(tmp[notNAs,c_lrr],tmp[notNAs,c_baf],tmp[notNAs,c_len],showGAPTemplate=T)
}


### coefficients of the pattern shrinkage
p_BAF<-result$coeff[1]
q_LRR<-result$coeff[2]

### matrix of coordinates of claster centers
Centr_CL<-result$Centr_CL

### matrix of clusters on the LRR x BAF plane
NETM<-result$NETM

### matrix of coordinates of subclones
SB_CL<-result$SB_CL

rm(result)

####### Final polish 

fName<-paste(outputPath,"proc_",fileNames[ii],".txt",sep="")
tmp<-read.delim(fName,header=T,sep="\t")
ttmp<-tmp[,4:5]

tmp<-tmp[,-c(4,5)]

datA<-read.table(sub(vect_Segm_pattern,vect_BAF_pattern,segFiles[ii]),header=F)
datA<-data.matrix(datA)
datA<-as.numeric(datA)
datA<-abs(datA-0.5)+0.5

datL<-read.table(sub(vect_Segm_pattern,vect_LR_pattern,segFiles[ii]),header=F)
datL<-data.matrix(datL)
datL<-as.numeric(datL)


##############################################
####### Summary figures

tmp<-getConfidence(tmp)
tmp<-shrinkReprTMP(tmp)
tmp<-updateMeans_FinalPolish(tmp,datA,datL,germHomozyg.mBAF.thr=0.95)

TMP<-tmp
TMP<-cbind(TMP[,1:3],TMP[,2:dim(TMP)[[2]]])
TMP[,4]<-SNP_annot[TMP[,c_is],C_Pos]
TMP[,5]<-SNP_annot[TMP[,c_if],C_Pos]
colnames(TMP)[4:5]<-c("PosSNPstart","PosSNPend")

fName<-sub(vect_Segm_pattern,"proc_",segFiles[ii])
write.table(TMP, file = fName,quote=F,row.names=F,sep="\t")

summaryPlots_perChrom(tmp,nameSample=fileNames[ii],SNP_annot, datA, datL, Centr_CL)

GAPplot(tmp,nameSample=fileNames[ii],SNP_annot,Centr_CL)

info<-summaryPlots(tmp,nameSample=fileNames[ii], SNP_annot, datA, datL, Centr_CL)

cat(c(fileNames[ii],info), file = paste(outputPath,output_infoFileName,sep=""),sep="\t",append=T,"\n")

}##ii



########################   END MAIN CYCLE


